% eegplugin_biosig1_0() - EEGLAB plugin for importing data using BIOSIG Matlab toolbox
%
% Usage:
%   >> eegplugin_biosig1_0(fig, trystrs, catchstrs);
%
% Inputs:
%   fig        - [integer]  EEGLAB figure
%   trystrs    - [struct] "try" strings for menu callbacks.
%   catchstrs  - [struct] "catch" strings for menu callbacks. 
%
% Create a plugin:
%   For more information on how to create an EEGLAB plugin see the
%   help message of eegplugin_besa() or visit http://www.sccn.ucsd.edu/eeglab/contrib.html
%
% Author: Arnaud Delorme, SCCN/INC, 25 Nov. 2003

%123456789012345678901234567890123456789012345678901234567890123456789012

% Copyright (C) 2003 Arnaud Delorme, Salk Institute, arno@salk.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1.07  USA

function eegplugin_biosig1_0(fig, trystrs, catchstrs)
    
  if nargin < 3
      error('eegplugin_eepimport requires 3 arguments');
  end;
    
  % add besa folder to path
  % -----------------------
  if ~exist('pop_biosig')
      p = which('eegplugin_biosig1_0');
      p = p(1:findstr(p,'eegplugin_biosig1_0.m')-1);
      addpath([ p 'biosig1.0' ] );
  end;
  
  % find import data menu
  % ---------------------
  menu = findobj(fig, 'tag', 'import data');
  
  % menu callbacks
  % --------------
  combio = [ trystrs.no_check '[EEG LASTCOM] = pop_biosig;'     catchstrs.new_and_hist ]; 
  
  % create menus if necessary
  % -------------------------
  if exist('sload') == 2  % detect BIOSIG
      pathsload   = which('sload');   pathsload   = pathsload(1:end-7);
      pathloadeeg = which('loadeeg'); pathloadeeg = pathloadeeg(1:end-9);
      if strcmpi(pathsload, pathloadeeg)
          disp('Warning: BIOSIG function ''loadeeg'' is in conflict with EEGLAB ''loadeeg'' function (Neuroscan)');
          disp('         Note: the ''loadeeg'' BIOSIG function is redundant with the BIOSIG ''sload'' function');
          disp( [ '         We advise that you remove ' which('loadeeg') ]);
      end;
      uimenu( menu, 'Label', 'From other formats using BIOSIG',  'CallBack', combio, 'Separator', 'on'); 
  else
      disp('BIOSIG menu not added: the BIOSIG toolbox must be installed');
  end;
